/************************************************************************
 This file is part of Kubiks.
 Kubiks is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, either version 3 of the License, or
 (at your option) any later version.
 Kubiks is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with Kubiks.  If not, see <http://www.gnu.org/licenses/>.
 *************************************************************************/

QoDesk.Kubiks = Ext.extend(Ext.app.Module, {

    moduleType : 'game',
    moduleId : 'kubiks-win',
    menuPath: 'StartMenu/Games',

	winAbout: false,
        ver: '0.1',
	kubiksColumns: 10,
	kubiksRows: 10,
	level: 0,
	timeDelay: 2000,
	curRow: 0,
	curCol: 0,
	curBlock: '',
	ArrBlocks: [],
	lastKey: {
		time: new Date().getTime(),
		action: ''
	},

   globalKeyMap: new Ext.KeyMap(document),
    
	init : function(){
		this.launcher = {
		text: 'Kubiks',
		tooltip: '<b>Kubiks</b><br />Tetris Like',
		iconCls:'Kubiks-icon',
		shortcutIconCls: 'kubiks-shortcut',
		handler : this.createWindow,
			scope: this
		};
	},

	createWindow : function(){
		var desktop = this.app.getDesktop();
		var win = desktop.getWindow('kubiks-win');
        
		if(!win){
			this.createArrBlocks();
			this.initField();

			this.timer = 0;
			this.gameStarted = false;
			this.counter = 0;

			 this.globalKeyMap.accessKey = function(key, handler, scope) {
				  var h = function(n, e) {
						e.preventDefault();
						handler.call(scope || this, n, e);
				  };
				  this.on(key, h, scope);
			 };

			var kubiksPanel = new Ext.form.FormPanel({
				id: 'kubiksPanel',
				tbar: [{
					id:'KubiksCounter',
//					disabled: true,
					text: this.renderScore(this.counter)
				}, {
					text: Kubiks.StartBtnText,
					iconCls:'Kubiks-start',
					tooltip: Kubiks.StartBtnToolTip,
					scope: this,
					handler: this.startGame
				},'->',{
					id:'KubiksTimer',
//					disabled: true,
					text:this.renderScore(this.timer)
				}],
				layout: 'fit',
				items: [this.grid]
			});

			win = desktop.createWindow({
				id: 'kubiks-win',
				title:'Kubiks',
				width:this.kubiksColumns * 16 + 26,
				height:this.kubiksRows * 19 + 78,
				resizable: false,
				iconCls: 'Kubiks-icon',
				shim: false,
				animCollapse: false,
				constrainHeader: true,
				layout: 'fit',
				minimizable: true,
				maximizable: false,
				 tools : [{
					scope: this,
					id:'gear',
					qtip:Kubiks.WinConfToolTip,
					handler:this.showConf
				 }, {
					scope: this,
					id:'help',
					qtip: Kubiks.WinAboutTitle,
					handler:this.showAbout
				 }],
				items: kubiksPanel
			});

		}
		win.show();
	},

	renderScore: function(v){
		if(v < 10){
			return '00'+v;
		}
		if(v < 100){
			return '0'+v;
		}
//		if(v > 99999){
//			return '99999';
//		}
		return v;
	},
    
	getTimer: function(){
		var now = new Date();
		var diff = now - this.timeStart;
		return this.renderScore(diff);
	},

	startTime: function(){
		if(!this.gameStarted){
			return;
		}
		if(!this.timeStart){
			var startTime = new Date();
			this.timeStart = startTime.format('U');
		}
		var tmr = Ext.getCmp('KubiksTimer');
		var now = new Date();
		var diff = now.format('U') - this.timeStart;
//		if(diff > 999){
//			return;
//		}
		if(tmr){
			tmr.setText(this.renderScore(diff));
		}
		var timerDelayTask = new Ext.util.DelayedTask(this.startTime, this);
		timerDelayTask.delay(500);
	},
    
	startGame: function(){
		var w = Ext.getCmp('kubiks-win');
		w.close();
		this.createWindow();
		this.counter = 0;
		var cntr = Ext.getCmp('KubiksCounter');
		cntr.setText(this.renderScore(this.counter));
		var tmr = Ext.getCmp('KubiksTimer');
		tmr.setText(this.renderScore(0));
		this.gameEnd = false;

		this.gameStarted = true;
		var startTime = new Date();
		this.timeStart = startTime.format('U');
		var timerDelayTask = new Ext.util.DelayedTask(this.startTime, this);
		timerDelayTask.delay(500);
		

		var moveDelayTask = new Ext.util.DelayedTask(this.moveDown, this);
		moveDelayTask.delay(this.timeDelay);
		this.getNextBlock();
		this.curRow = 0;
		this.curCol = Math.floor(Math.random() * (this.kubiksColumns - 1 - this.ArrBlocks[this.ArrBlocks.length - 1].length));	
	},
    
   moveDown: function(){
		if(!this.gameStarted){
			return;
		}
		if(!this.moveBlocks('down')){
			this.setBlocks();
			this.removeRows();
			this.getNextBlock();
			this.curRow = 0;
			this.curCol = Math.floor(Math.random() * (this.kubiksColumns - 1 - this.ArrBlocks[this.ArrBlocks.length - 1].length));	
			
			if(!this.canMove()){
				this.gameOver();
				return;
			}
			
			this.timeDelay--;
		}
		
		var moveDelayTask = new Ext.util.DelayedTask(this.moveDown, this);
		moveDelayTask.delay(this.timeDelay);
   },
   
	gameOver: function(){
		this.gameStarted = false;
		this.gameEnd = true;
		var tmr = Ext.getCmp('KubiksTimer');
		var txt = "";
		if(tmr){
			txt = tmr.getText();
		}
		
		Ext.Msg.alert(Kubiks.MsgGameOverTitle, String.format(Kubiks.MsgGameOverText, this.counter, txt));
	},
	
	initField: function(){
		var RecArr = [];
		var i;

		var checkColumn = [];
		for(i = 0; i < this.kubiksColumns; i++)
		{
			RecArr[i] = 'c' + i;
			checkColumn[i] = {
				dataIndex: 'c' + i, 
				width: 16, 
				sortable: false,
				resizable: false,
				hideable: false,
				fixed : true,
				align: 'center',
				renderer : function(v, p, record){
					p.css += ' x-grid3-check-col-td'; 
					if(v == 'X'){
						return '<div class="kubiks-empty">&#160;</div>';
					}
					if(v == '1'){
						return '<div class="kubiks-empty">&#160;</div>';
					}
					return '';
				}
			};
		}


		var dataDS = [];
		for(i = 0; i < this.kubiksRows; i++){
			dataDS[i] = [];
			for(var j = 0; j < this.kubiksColumns; j++){
				dataDS[i][j] = "";
			}
		}

		if(this.ds){
			this.ds = '';
		}
		
		this.ds = new Ext.data.SimpleStore({
			fields: RecArr, 
			data : dataDS
		});

		var colModel = new Ext.grid.ColumnModel(checkColumn);

		this.grid = new Ext.grid.GridPanel({ 
			cm: colModel,
			height: this.kubiksRows * 20 + 10, 
			iconCls: 'icon-grid',
			id: 'kubiksGrid',
			loadMask: true,
			header: false,
			disableSelection: true,
			ds: this.ds,
			listeners:{
				scope: this,
				render: function(grid){
					this.globalKeyMap.accessKey({key: Ext.EventObject.LEFT, ctrl:false}, function(){this.moveBlocks('left');}, this);
					this.globalKeyMap.accessKey({key: Ext.EventObject.LEFT, ctrl:true}, function(){this.moveBlocks('leftEnd');}, this);
					this.globalKeyMap.accessKey({key: Ext.EventObject.RIGHT, ctrl:false}, function(){this.moveBlocks('right');}, this);
					this.globalKeyMap.accessKey({key: Ext.EventObject.RIGHT, ctrl:true}, function(){this.moveBlocks('rightEnd');}, this);
					this.globalKeyMap.accessKey({key: Ext.EventObject.UP, ctrl:false}, function(){this.moveBlocks('rotate');}, this);
					this.globalKeyMap.accessKey({key: Ext.EventObject.UP, ctrl:true}, function(){this.moveBlocks('rotateCC');}, this);
					this.globalKeyMap.accessKey({key: Ext.EventObject.DOWN, ctrl:false}, function(){this.moveBlocks('down');}, this);
					this.globalKeyMap.accessKey({key: Ext.EventObject.DOWN, ctrl:true}, function(){this.moveBlocks('drop');}, this);
				}
			}
		});

	},
	
	makeMoveBlocks: function(){
		var r = this.curRow;
		var c = this.curCol;
		var block = this.curBlock;
		var record;
		var fieldName;
		var data;
		
		
		for(var i = 0; i < this.kubiksRows; i++){
			record = this.grid.getStore().getAt(i);  
			for(var j = 0; j < this.kubiksColumns; j++){
				fieldName = this.grid.getColumnModel().getDataIndex(j); 
				data = record.get(fieldName);
				if(data == "1"){
					record.set(fieldName, "");
				}
			}
		}

		for(var row = 0; row < block.length; row++){
			if(r - row < 0){
				continue;
			}
			record = this.grid.getStore().getAt(r - row);  
			for(var col = 0; col < block[row].length ; col++){
				if(col + c >= this.kubiksColumns){
					break;
				}
				fieldName = this.grid.getColumnModel().getDataIndex(col + c); 
				data = record.get(fieldName);
				if(block[row][col] == 1){
					record.set(fieldName, "1");
				}
			}
		}
		this.grid.store.commitChanges();
	},
	
   moveBlocks: function(action){
   	var timeNow = new Date().getTime();
	
   	if(timeNow - this.lastKey.time < 50 && action == this.lastKey.action){
   		return;
   	}
   	else{
			this.lastKey.time = timeNow;
			this.lastKey.action = action;
   	}
   	
   	switch(action){
   		case 'left':
   			if(this.curCol > 0){
   				this.curCol--;
   				if(this.curCol < 0){
   					this.curCol = 0;
   					return false;
   				}
					if(this.canMove()){
						return true;
					}
					else{
	   				this.curCol++;
	   				return false;
					}
   			}
   			break;
   		case 'leftEnd':
   			while(this.curCol > 0){
   				this.curCol--;
					if(!this.canMove()){
	   				this.curCol++;
	   				return true;
					}
   			}
   			break;
   		case 'right':
   			if(this.curCol + this.curBlock[0].length - 1 < this.kubiksColumns - 1){
   				this.curCol++;
   				if(this.curCol > this.kubiksColumns - this.curBlock[0].length){
   					this.curCol = this.kubiksColumns - this.curBlock[0].length;
   					return false;
   				}
					if(this.canMove()){
						return true;
					}
					else{
	   				this.curCol--;
	   				return false;
					}
   			}
   			break;
   		case 'rightEnd':
   			while(this.curCol + this.curBlock[0].length - 1 < this.kubiksColumns - 1){
   				this.curCol++;
					if(!this.canMove()){
	   				this.curCol--;
	   				return true;
					}
   			}
   			break;
   		case 'down':
   			if(this.curRow < this.kubiksRows - 1){
   				this.curRow++;
					if(this.canMove()){
						return true;
					}
					else{
						this.curRow--;
						return false;
					}
   			}
   			break;
   		case 'drop':
   			while(this.curRow < this.kubiksRows - 1){
   				this.curRow++;
					if(!this.canMove()){
						this.curRow--;
						return true;
					}
   			}
   			break;
   		case 'rotate':
   			this.rotate(false);
				if(this.canMove()){
					return true;
				}
				else{
					this.rotate(true);
					return false;
				}
   			break;
   		case 'rotateCC':
   			this.rotate(true);
				if(this.canMove()){
					return true;
				}
				else{
					this.rotate(false);
					return false;
				}
   			break;
   	}
		return false;
   },
   
   setBlocks: function(){
		var r = this.curRow;
		var c = this.curCol;
		
		var block = this.curBlock;

		for(var row = 0; row < block.length; row++){
			if(r - row < 0){
				continue;
			}
			var record = this.grid.getStore().getAt(r - row);  
			for(var col = 0; col < block[row].length; col++){
				if(col + c >= this.kubiksColumns){
					break;
				}
				var fieldName = this.grid.getColumnModel().getDataIndex(col + c); 
				var data = record.get(fieldName);

				if(block[row][col] == 1){
					record.set(fieldName, "X");
				}
			}
		}

		this.grid.store.commitChanges();
   },
	
	canMove: function(){
		var r = this.curRow;
		var c = this.curCol;
		var block = this.curBlock;

		for(var row = 0; row < block.length; row++){
			if(r - row < 0){
				continue;
			}
			var record = this.grid.getStore().getAt(r - row);  
			for(var col = 0; col < block[row].length; col++){
				if(col + c >= this.kubiksColumns){
					break;
				}
				var fieldName = this.grid.getColumnModel().getDataIndex(col + c); 
				var data = record.get(fieldName);

				if(data == "X" && block[row][col] == 1){
					return false;
				}
			}
		}
		
		this.makeMoveBlocks();
		return true;
	},

	removeRows: function(){
		for(var r = 0; r < this.kubiksRows; r++){
			this.removeRow(r);
		}
	},
	
	removeRow: function(r){
		var cntr = 0;
		var record = this.grid.getStore().getAt(r);  
		
		var fieldName;
		var data;
		var c;
		
		for(c = 0; c < this.kubiksColumns; c++){
			fieldName = this.grid.getColumnModel().getDataIndex(c); 
			data = record.get(fieldName);
			if(data == "X"){
				cntr++;
			}
		}

		if(cntr == this.kubiksColumns){
			for(c = 0; c < this.kubiksColumns; c++){
				fieldName = this.grid.getColumnModel().getDataIndex(c); 
				for(var i = r; i > 0; i--){
					var rec_old = this.grid.getStore().getAt(i);  
					var rec_new = this.grid.getStore().getAt(i - 1);  
					data = rec_new.get(fieldName);
					rec_old.set(fieldName, data);
				}
				
				var rec = this.grid.getStore().getAt(0);  
				rec.set(fieldName, "");
			}

			this.grid.store.commitChanges();
			

			this.counter++;
			var cntrCmp = Ext.getCmp('KubiksCounter');
			cntrCmp.setText(this.renderScore(this.counter));
		}
	},
	
	rotate: function(cc){
		var rotateCC = true;
		if(!cc){
			rotateCC = false;
		}
		var block = [];

		for(var row = 0; row < this.curBlock.length; row++){
			for(var col = 0; col < this.curBlock[row].length; col++){
				if(!rotateCC){
					if(!block[this.curBlock[row].length - col - 1]){
						block[this.curBlock[row].length - col - 1] = [];
					}
					block[this.curBlock[row].length - col - 1][row] = this.curBlock[row][col];
				}
				else{
					if(!block[col]){
						block[col] = [];
					}
					block[col][this.curBlock.length - row - 1] = this.curBlock[row][col];
				}
			}
		}
	
		this.curBlock = block;
	},
	
	getNextBlock: function(){
		var rotateRand = Math.floor(Math.random() * 4);
		this.curBlock = this.ArrBlocks[Math.floor(Math.random() * (this.ArrBlocks.length))];	
		for(var i = 0; i < rotateRand; i++){
			this.rotate(true);
		}
	},
	
	createArrBlocks: function(){
		this.ArrBlocks = [[[1,1], 
 								 [1,1]],
		
								[[1,1,1,1]],
		
								[[1,1,1],
								 [1,0,0]],
		
								[[1,1,1],
								 [0,0,1]],
		
								[[1,1,1],
								 [0,1,0]],
		
								[[1,1,0],
								 [0,1,1]],
		
								[[0,1,1],
								 [1,1,0]]];
	},
	

	setParams: function(l, c, r, s){
		this.level = l;
		this.kubiksColumns = c;
		this.kubiksRows = r;
		this.timeDelay = s * 1000; 
		this.ds = {};

		var custC = Ext.getCmp('kubiksColumns');
		if(custC){
			custC.setValue(this.kubiksColumns);
		}
		var custR = Ext.getCmp('kubiksRows');
		if(custR){
			custR.setValue(this.kubiksRows);
		}
		var custB = Ext.getCmp('kubiksSec');
		if(custB){
			custB.setValue(this.timeDelay / 1000.0);
		}
	},

	
	showConf: function(){
		var FormConf = new Ext.FormPanel({
			frame: true,
			bodyStyle: 'padding:5px',
			items: [{
				xtype: 'fieldset',
				title: Kubiks.WinConfFieldSetTitle0,
				autoHeight: true,
				autoWidth:true,
				labelWidth: 55,
				anchor: '95%',
				items: [{
					xtype: 'radio',
					id: 'Kubiks-level-0',
					boxLabel: Kubiks.WinConfFieldSetLabel0,
					checked: (this.level === 0) ? true : false,
					hideLabel: true,
					listeners: {
						scope: this,
						check: function(field, checked){
							if(checked && this.level !== 0){
								this.setParams(0, 10, 10, 2);

								var l1 = Ext.getCmp('Kubiks-level-1');
								l1.setValue(false);
								var l2 = Ext.getCmp('Kubiks-level-2');
								l2.setValue(false);

								var w = Ext.getCmp('kubiks-win');
								w.close();
								this.createWindow();
							}
						}
					}
				},{
					xtype: 'radio',
					id: 'Kubiks-level-1',
					boxLabel: Kubiks.WinConfFieldSetLabel1,
					checked: (this.level === 1) ? true : false,
					hideLabel: true,
					listeners: {
						scope: this,
						check: function(field, checked){
							if(checked && this.level !== 1){
								this.setParams(1, 15, 15, 1.5);

								var l0 = Ext.getCmp('Kubiks-level-0');
								l0.setValue(false);
								var l2 = Ext.getCmp('Kubiks-level-2');
								l2.setValue(false);

								var w = Ext.getCmp('kubiks-win');
								w.close();
								this.createWindow();
							}
						}
					}
				},{
					xtype: 'radio',
					id: 'Kubiks-level-2',
					boxLabel: Kubiks.WinConfFieldSetLabel2,
					checked: (this.level === 2) ? true : false,
					hideLabel: true,
					listeners: {
						scope: this,
						check: function(field, checked){
							if(checked && this.level !== 2){
								this.setParams(2, 30, 20, 1);

								var l0 = Ext.getCmp('Kubiks-level-0');
								l0.setValue(false);
								var l1 = Ext.getCmp('Kubiks-level-1');
								l1.setValue(false);

								var w = Ext.getCmp('kubiks-win');
								w.close();
								this.createWindow();
							}
						}
					}
				}]
			},{
            xtype:'fieldset',
            id: 'kubiks-custom-config',
            checkboxToggle:true,
				title: Kubiks.WinConfFieldSetTitle1,
            autoHeight:true,
            defaultType: 'textfield',
            collapsed: (this.level === 3) ? false : true,
            items :[{
					fieldLabel: Kubiks.WinConfFieldSet1Label0,
					id: 'kubiksColumns',
					value: this.kubiksColumns,
					allowBlank:false,
					listeners: {
             		scope: this,
             		change: function(field, newValue, oldValue){
             			if(newValue < 5){
             				field.setValue(5);
             			}
             			if(newValue > 60){
             				field.setValue(60);
             			}
             		}
					}
				},{
					fieldLabel: Kubiks.WinConfFieldSet1Label1,
					id: 'kubiksRows',
					value: this.kubiksRows,
					allowBlank:false,
					listeners: {
             		scope: this,
             		change: function(field, newValue, oldValue){
             			if(newValue < 5){
             				field.setValue(5);
             			}
             			if(newValue > 30){
             				field.setValue(30);
             			}
             		}
					}
				},{
					fieldLabel: Kubiks.WinConfFieldSet1Label2,
					id: 'kubiksSec',
					value: this.timeDelay / 1000.0,
					allowBlank:false,
					listeners: {
             		scope: this,
             		change: function(field, newValue, oldValue){
             			if(newValue < 0.1){
             				field.setValue(0.1);
             			}
             			if(newValue > 5){
             				field.setValue(5);
             			}
             		}
					}
				}],
				buttons: [{
					text: Kubiks.WinConfApply,
					scope: this,
					handler: function(){
						var custC = Ext.getCmp('kubiksColumns');
						var c = 10;
						if(custC){
							c = custC.getValue();
						}
						var custR = Ext.getCmp('kubiksRows');
						var r = 10;
						if(custR){
							r = custR.getValue();
						}
						var custS = Ext.getCmp('kubiksSec');
						var s = 2;
						if(custS){
							s = custS.getValue();
						}
						this.setParams(3, c, r, s);
						var l0 = Ext.getCmp('Kubiks-level-0');
						l0.setValue(false);
						var l1 = Ext.getCmp('Kubiks-level-1');
						l1.setValue(false);
						var l2 = Ext.getCmp('Kubiks-level-2');
						l2.setValue(false);

						var w = Ext.getCmp('kubiks-win');
						w.close();
						this.createWindow();
					}
				}],
				listeners: {
					scope: this,
					expand: function(panel){
						var l0 = Ext.getCmp('Kubiks-level-0');
						l0.setValue(false);
						var l1 = Ext.getCmp('Kubiks-level-1');
						l1.setValue(false);
						var l2 = Ext.getCmp('Kubiks-level-2');
						l2.setValue(false);
					},
					collapse: function(panel){
						var l0 = Ext.getCmp('Kubiks-level-0');
						l0.setValue(true);
						var l1 = Ext.getCmp('Kubiks-level-1');
						l1.setValue(false);
						var l2 = Ext.getCmp('Kubiks-level-2');
						l2.setValue(false);
					}
				}
        }]
		});



		var winConf = new Ext.Window({
			scope: this,
			animateEl: 'mod-feed-btn',
			title: Kubiks.WinConfTitle,
			layout: 'fit',
			modal: true,
			iconCls: 'Kubiks-icon-conf',
			width: 450,
			height: 400,
			bodyStyle: 'padding:5px',
			plain: true,
			items: FormConf,
			buttons: [{
				text: Kubiks.WinConfClose,
				scope: this,
				handler: function(){
					winConf.hide();
				}
			}]
		});
		winConf.show(this);
	}, 

	showAbout: function(){
		if(!this.winAbout) {
			this.winAbout = new Ext.Window({
				layout: 'fit',
				width: 515,
				height: 450,
				iconCls: 'Kubiks-icon-about',
				modal: true,
				title: Kubiks.WinAboutTitle,
				closeAction: 'hide',
				plain: true,
				bodyStyle: 'color:#000',
				items: new Ext.TabPanel({
					autoTabs: true,
					activeTab: 0,
					border: false,
					defaults: {
						autoScroll: true
					},
					items: [{
							title: Kubiks.WinAboutTab0,
							html: '<div id="Kubiks-about"><img src="system/modules/Kubiks/img/kubiks_logo.png" alt="Kubiks" /></div><div id="Kubiks-about-info">Kubiks ver ' + this.ver + ' (c) 2008, Andriy Levytskyy - <a href="mailto:andriy.levytskyy@gmail.com">andriy.levytskyy@gmail.com</a></div>'
						}, {
							title: Kubiks.WinAboutTab1,
							bodyStyle: 'padding:15px',
							html: '<div id="Kubiks-credit"><ul>' + 
										'<li>' + Kubiks.WinAboutTab1Key0 + '</span></li>' + 
										'<li>' + Kubiks.WinAboutTab1Key1 + '</span></li>' + 
										'<li>' + Kubiks.WinAboutTab1Key2 + '</span></li>' + 
										'<li>' + Kubiks.WinAboutTab1Key3 + '</span></li>' + 
										'<li>' + Kubiks.WinAboutTab1Key4 + '</span></li>' + 
										'<li>' + Kubiks.WinAboutTab1Key5 + '</span></li>' + 
										'<li>' + Kubiks.WinAboutTab1Key6 + '</span></li>' + 
										'<li>' + Kubiks.WinAboutTab1Key7 + '</span></li>' + 
								'</ul></div>'
						}, {
							title: Kubiks.WinAboutTab2,
							bodyStyle: 'padding:15px',
							html: '<div id="Kubiks-credit"><ul>' + 
										'<li><a href="http://extjs.com">ExtJs Team</a><br><span class="Kubiks-credit-info">' + Kubiks.WinAboutTab2Credits0 + '</span></li>' + 
										'<li><a href="http:// famfamfam.com">famfamfam.com</a><br><span class="Kubiks-credit-info">' + Kubiks.WinAboutTab2Credits1 + '</span></li>' + 
										'<li>Yannick Torr&egrave;s - <a href="mailto:yannick.torres@keliglia.com">yannick.torres@keliglia.com</a> <br><span class="Kubiks-credit-info">' + Kubiks.WinAboutTab2Credits2 + '</span></li>' + 
								'</ul></div>'
						}, {
							title: Kubiks.WinAboutTab3,
							autoLoad: {
								url: 'system/modules/Kubiks/license_LGPL_v2.txt'
							}
					}]
				}),
				buttons: [{
					scope:this,
					text: Kubiks.WinAboutClose,
					handler: function(){
						this.winAbout.hide();
					}
				}]
			});
		}
		this.winAbout.show(this);
	} 
	
});